@@ -2,8 +2,7 @@
 Datasets used with the Precomputed Connectome
 
 """
-
-from nilearn import image
+import nibabel as nib
 import importlib.resources as pkg_resources
 
 datasets = {
@@ -13,6 +12,9 @@ datasets = {
     "MNI152_T1_1mm_brain": "MNI152_T1_1mm_brain.nii.gz",
     "MNI152_T1_1mm_brain_mask": "MNI152_T1_1mm_brain_mask.nii.gz",
     "MNI152_T1_1mm_brain_mask_dil": "MNI152_T1_1mm_brain_mask_dil.nii.gz",
+    "fs5_mask": "fs5_mask.gii",
+    "fs5_mask_lh": "fs5_mask_lh.gii",
+    "fs5_mask_rh": "fs5_mask_rh.gii",
 }
 
 
@@ -23,7 +25,7 @@ def get_img(ds):
         ds (str) : Name of the image. Options are as follows:
 
             Volume Masks
-            ---
+            ------------
             "MNI152_T1_2mm_brain"
             "MNI152_T1_2mm_brain_mask"
             "MNI152_T1_2mm_brain_mask_dil"
@@ -31,6 +33,12 @@ def get_img(ds):
             "MNI152_T1_1mm_brain_mask"
             "MNI152_T1_1mm_brain_mask_dil"
 
+            Surface Masks
+            -------------
+            "fs5_mask"
+            "fs5_mask_lh"
+            "fs5_mask_rh"
+
     Returns:
         Niimg-like object
     """
@@ -39,7 +47,7 @@ def get_img(ds):
     from . import data
 
     with pkg_resources.path(data, fname) as datafile:
-        return image.load_img(str(datafile))
+        return nib.load(str(datafile))
 
 
 def get_img_path(ds):
@@ -49,7 +57,7 @@ def get_img_path(ds):
         ds (str) : Name of the image. Options are as follows:
 
             Volume Masks
-            ---
+            ------------
             "MNI152_T1_2mm_brain"
             "MNI152_T1_2mm_brain_mask"
             "MNI152_T1_2mm_brain_mask_dil"
@@ -57,6 +65,12 @@ def get_img_path(ds):
             "MNI152_T1_1mm_brain_mask"
             "MNI152_T1_1mm_brain_mask_dil"
 
+            Surface Masks
+            -------------
+            "fs5_mask"
+            "fs5_mask_lh"
+            "fs5_mask_rh"
+
     Returns:
         str : Path to image
     """
